==> payment-ui-components-2.1.5.tgz: package/README.md <==
## Payment UI Components
A library of common components built with Vue JS. 

### Available components
* [Spinner](https://github.com/devcode-git/payment-ui-components/blob/master/src/Spinner)
* [Input](https://github.com/devcode-git/payment-ui-components/blob/master/src/Input)
* [ComboBox](https://github.com/devcode-git/payment-ui-components/blob/master/src/ComboBox)
* [ComboButton](https://github.com/devcode-git/payment-ui-components/blob/master/src/ComboButton)
* [Button](https://github.com/devcode-git/payment-ui-components/blob/master/src/Button)
* [Dropdown](https://github.com/devcode-git/payment-ui-components/blob/master/src/Dropdown)
* [SlideInContent](https://github.com/devcode-git/payment-ui-components/blob/master/src/SlideInContent)

#### Looking for the Grid or AceEditor component? They have moved to [payment-ui-bo-components](https://github.com/devcode-git/payment-ui-bo-components)

### Making changes?
Remember to update the [changelog](https://github.com/devcode-git/payment-ui-components/blob/master/changes.md)
If you increment the version number in package.json and commit it it will trigger an auto-deploy to [JFrog npm registry](https://bambora.jfrog.io/bambora/webapp/#/artifacts/browse/tree/General/npm-local/@bambora/payment-ui-components/-/@bambora)

### To use package fetched from @Bambora-npm-registry

```
1) Login to https://bambora.onelogin.com/login and navigate to Npm Artifactory (JFrog)
2) Click your username (top right) and generate an API-key
3) Cd to your project in Terminal

(username = firstname.lastname) (password = API-key)
4) run curl -u username:password https://bambora.jfrog.io/bambora/api/npm/npm-local/auth/bambora > .npmrc
5) I your package.json, add "@bambora/payment-ui-components": "^N.N.N" as a dependency

// Your .npmrc should look like:

@bambora:registry=https://bambora.jfrog.io/bambora/api/npm/npm-local/
//bambora.jfrog.io/bambora/api/npm/npm-local/:_password=JFROG_PASSWORD
//bambora.jfrog.io/bambora/api/npm/npm-local/:username=simon.solders
//bambora.jfrog.io/bambora/api/npm/npm-local/:email=simon.solders@bambora.com
//bambora.jfrog.io/bambora/api/npm/npm-local/:always-auth=true

//Edit your package.json and add to dependencies:
"@bambora/payment-ui-components": "latest"

npm install  //install your project
```

**NOTE**

You must also be added to the oneLogin sec AD-group.
Ask to be added in the **sto-devops** group in Slack.


### Local development

```
cd to payment-ui-components
npm link

cd to your project
npm link payment-ui-components
npm start

//import the component(s) you wish to develop from payment-ui-components (NOTE not with the @bambora-scope)
import { Button } from 'payment-ui-components'
```

When you have made changes to payment-ui-components you have to transpile it
```
npm run build:all //transpiles everything in /src to ES2015 and puts it in /dist
```
If your app as Hot-modules-reload (HMR) enabled it will auto-reload and show your changes.

==> payment-ui-components-2.1.6.tgz: package/README.md <==
## Payment UI Components
A library of common components built with Vue JS. 

### Available components
* [Spinner](https://github.com/devcode-git/payment-ui-components/blob/master/src/Spinner)
* [Input](https://github.com/devcode-git/payment-ui-components/blob/master/src/Input)
* [ComboBox](https://github.com/devcode-git/payment-ui-components/blob/master/src/ComboBox)
* [ComboButton](https://github.com/devcode-git/payment-ui-components/blob/master/src/ComboButton)
* [Button](https://github.com/devcode-git/payment-ui-components/blob/master/src/Button)
* [Dropdown](https://github.com/devcode-git/payment-ui-components/blob/master/src/Dropdown)
* [SlideInContent](https://github.com/devcode-git/payment-ui-components/blob/master/src/SlideInContent)

#### Looking for the Grid or AceEditor component? They have moved to [payment-ui-bo-components](https://github.com/devcode-git/payment-ui-bo-components)

### Making changes?
Remember to update the [changelog](https://github.com/devcode-git/payment-ui-components/blob/master/changes.md)

### To use package fetched from @Bambora-npm-registry

```
//Edit your package.json and add to dependencies:
"payment-ui-components": "latest"

npm install  //install your project
```

### Local development

```
cd to payment-ui-components
npm link

cd to your project
npm link payment-ui-components
npm start

//import the component(s) you wish to develop from payment-ui-components (NOTE not with the @bambora-scope)
import { Button } from 'payment-ui-components'
```

When you have made changes to payment-ui-components you have to transpile it
```
npm run build:all //transpiles everything in /src to ES2015 and puts it in /dist
```
If your app as Hot-modules-reload (HMR) enabled it will auto-reload and show your changes.
